@@ -27,7 +27,7 @@ import socket
 
 
 # The current version of duplicity
-version = "0.7.16"
+version = "0.7.18.1"
 
 # Prefix for all files (appended before type-specific prefixes)
 file_prefix = ""
@@ -297,9 +297,6 @@ par2_options = ""
 # Whether to enable gio backend
 use_gio = False
 
-# If set, collect only the file status, not the whole root.
-file_changed = None
-
 # delay (in seconds) before next operation after failure
 backend_retry_delay = 30
 
